## Emerging technologies Management and Risk evaluation on distribution Grids Evolution (EMERGE)

<p align="center"> 
<img src="docs/images/logo.svg" width="150" style="display:flex;justify-content:center;">
<p align="center">Modern tool for exploring and performing DER impact assessment for power distribution networks. </p>
</p>

![GitHub all releases](https://img.shields.io/github/downloads/NREL/emerge/total?logo=Github&logoColor=%2300ff00&style=flat-square)
![GitHub repo size](https://img.shields.io/github/repo-size/nrel/emerge?style=flat-square)
![CodeFactor Grade](https://img.shields.io/codefactor/grade/github/nrel/emerge?color=%23ff0000&logo=python&logoColor=%2300ff00&style=flat-square)
[![GitHub license](https://img.shields.io/github/license/NREL/emerge?style=flat-square)](https://github.com/NREL/emerge/blob/main/LICENSE.txt)
[![GitHub issues](https://img.shields.io/github/issues/NREL/emerge?style=flat-square)](https://github.com/NREL/emerge/issues)
![GitHub top language](https://img.shields.io/github/languages/top/nrel/emerge?style=flat-square)

[Check for full documentation here.](https://nrel.github.io/EMeRGE/)

### :wave: Welcome to EMERGE Repository !

EMERGE allows user quickly analyze the distribution feeder by providing access to simple yet powerful visualization platform. You can compute metrics for both snapshot and time series simulations (note we are still actively developing new features on this so things might change rapidly. if you have any feedback reach out to us by creating issue).

:rocket: We would appreciate if you can star our repo. 




